/*******************************************************************************/
/* This program is for demonstrating how institution and branch data can be    */ 
/* loaded for FinCEN regulatory reports.                                       */
/* The data should be adjusted to match with your organizational information.  */
/*******************************************************************************/
%macro rc_load_sample_location; 

/*******************************************************************************/
/* Sample transmitter data.                                                    */ 
/* Shared by all finCEN forms.                                                 */
/* There should be only one current record for each tax ID.                    */
/* The effective period should not have gaps or overlaps.                      */
/* Transmitter_key should be unique.                                           */
/*******************************************************************************/

data fincen_transmitter;
    if 0 then set rc_cfg.fincen_transmitter;
    form_config_key=301;

    transmitter_key=1;
    transmitter_name='SAS Institute Inc.';                                                                                                    
    transmitter_address='100 SAS Campus Drive';                                                                                           
    transmitter_city_name='Cary';                                                                                               
    transmitter_state_code='NC';                                                                                              
    transmitter_zip_code='27513';                                                                                                
    transmitter_country_code='US' ;
    transmitter_contact_name='SAS TECHNICAL SUPPORT'; 
    transmitter_telephone='9196778008';                                                                                                                                                                                          
    transmitter_tax_id='111222333';                                                                                                
    transmitter_control_code='TBSATEST'; 
    effective_from_date=mdy(1,1,2000)*24*3600;
    effective_to_date=mdy(1,1,5999)*24*3600;
    entity_number=transmitter_tax_id;
    entity_name=transmitter_name;
    output;
    transmitter_key=2;
    form_config_key=302;
    transmitter_contact_name='SAS TECHNICAL SUPPORT CTR/DOEP'; 
    output;
    transmitter_key=3;
    form_config_key=303;
     transmitter_contact_name='SAS TECHNICAL SUPPORT CTR/DOEP'; 
    output;
run; 




%if &rc_debug = N %then
%do;
    proc sql;

         delete from rc_cfg.fincen_transmitter;
         
    quit;
    
    proc append base=rc_cfg.fincen_transmitter data=fincen_transmitter  force;
    run;
     
%end;


/*********************************************************************************/
/* Sample institution data.                                                      */
/* This example shows that the institution information is the same for all forms */
/* but the contact information can be different.                                 */
/*                                                                               */ 
/* There should be only one current record for each form.                        */
/* The effective period should not have gaps or overlaps.                        */
/* Institution_key should be unique.                                             */
/*********************************************************************************/

data fincen_institution;

    if 0 then set rc_cfg.fincen_institution;
    
    institution_id='111222333';    
    /* using institution key as record key */
    institution_key=1;
    institution_legal_name='SAS Institute Inc.'; 
    institution_alternate_name='SAS';  
    institution_address='100 SAS Campus Drive';                                                                                           
    institution_city_name='Cary';                                                                                               
    institution_state_code='NC';                                                                                              
    institution_zip_code='27513';                                                                                                
    institution_country_code='US' ;                                                                                                                                                                                     
    institution_tax_id='123123123'; 
    institution_prim_fed_reg_code='C'; 
    institution_tax_id_type='A';
    institution_type_code='E';
    institution_id_type_code='D';    
    institution_sf_type_code='DF';
    institution_alternate_name='';
    institution_gaming_type_code = '';
    institution_gaming_type_other='';

    entity_number=institution_tax_id;
    entity_name=institution_legal_name;

    /* use default_ind to indicate which institution is the filing institution */    
    default_ind = 'Y'; 

    /* contact information */ 
    contact_office='COMPLIANCE';
    contact_name='';
    contact_title='SAR COMPLIANCE OFFICER';
    contact_phone_number='9196778008';
    contact_phone_extension='';
    effective_from_date=mdy(1,1,2000)*24*3600;
    effective_to_date=mdy(1,1,5999)*24*3600;
    form_config_key=301;
    output;
    institution_key=2;
    form_config_key=302;
    contact_office='CTR/DOEP COMPLIANCE';
    contact_name='';
    contact_title='';
    contact_phone_number='9196778008';
    contact_phone_extension='';
    output;
    institution_key=3;
    form_config_key=303;
    contact_office='CTR/DOEP COMPLIANCE';
    contact_name='OFFICE A';
    contact_title='COMPLIANCE OFFICER';
    contact_phone_number='9196778008';
    contact_phone_extension='';

    output;

    /* This sample demonstrates how multiple institutions can be defined for SAR 2B institution selection list */
    institution_id='222111333';    
    institution_key=4;  
    institution_legal_name='SAS Institute Inc. 2'; 
    institution_alternate_name='SAS 2';  
    institution_address='100 SAS Campus Drive 2' ;                                                                                           
    institution_city_name='Cary 2';                                                                                               
    institution_state_code='NC';                                                                                              
    institution_zip_code='27513';                                                                                                
    institution_country_code='US' ;                                                                                                                                                                                     
    institution_tax_id='222111333'; 
    institution_prim_fed_reg_code='C'; 
    institution_tax_id_type='A';
    institution_type_code='A';
    institution_id_type_code='D';
    institution_sf_type_code='';
    institution_alternate_name='';
    institution_gaming_type_code = 'Z';
    institution_gaming_type_other='Other gaming type';
    /* contact information */ 
    contact_office='COMPLIANCE';
    contact_name='';
    contact_title='SAR COMPLIANCE OFFICER';
    contact_phone_number='9196778008';
    contact_phone_extension='';
    effective_from_date=mdy(1,1,2000)*24*3600;
    effective_to_date=mdy(1,1,5999)*24*3600;
    form_config_key=301;

    entity_number=institution_tax_id;
    entity_name=institution_legal_name;

    /* use default_ind to indicate that this institution is NOT the filing institution */    
    default_ind = 'N';
    output;

    institution_id='333111222';    
    institution_key=5;  
    institution_legal_name='SAS Institute Inc. 3'; 
    institution_alternate_name='SAS 2';  
    institution_address='100 SAS Campus Drive 3' ;                                                                                           
    institution_city_name='Cary 3';                                                                                               
    institution_state_code='NC';                                                                                              
    institution_zip_code='27513';                                                                                                
    institution_country_code='US' ;                                                                                                                                                                                     
    institution_tax_id='333111222'; 
    institution_prim_fed_reg_code='C'; 
    institution_tax_id_type='A';
    institution_type_code='A';
    institution_id_type_code='A';
    institution_sf_type_code='';
    institution_alternate_name='';
    institution_gaming_type_code = 'A';
    institution_gaming_type_other='Other gaming type';
    /* contact information */ 
    contact_office='COMPLIANCE';
    contact_name='';
    contact_title='SAR COMPLIANCE OFFICER';
    contact_phone_number='9196778008';
    contact_phone_extension=''; 
    effective_from_date=mdy(1,1,2000)*24*3600;
    effective_to_date=mdy(1,1,5999)*24*3600;
    form_config_key=301;

    entity_number=institution_tax_id;
    entity_name=institution_legal_name;


    /* use default_ind to indicate that this institution is NOT the filing institution */    
    default_ind = 'N';
    output;

    /* example of unknown institution of 2B */
    institution_id='';    
    institution_key=6;  
    institution_legal_name=''; 
    institution_alternate_name='';  
    institution_address='' ;                                                                                           
    institution_city_name='';                                                                                               
    institution_state_code='';                                                                                              
    institution_zip_code='';                                                                                                
    institution_country_code='' ;                                                                                                                                                                                     
    institution_tax_id=''; 
    institution_prim_fed_reg_code=''; 
    institution_tax_id_type='';
    institution_type_code='';
    institution_id_type_code='';
    institution_sf_type_code='';
    institution_alternate_name='';
    institution_gaming_type_code = '';
    institution_gaming_type_other='';
    /* contact information */ 
    contact_office='COMPLIANCE';
    contact_name='';
    contact_title='SAR COMPLIANCE OFFICER';
    contact_phone_number='9196778008';
    contact_phone_extension=''; 
    effective_from_date=mdy(1,1,2000)*24*3600;
    effective_to_date=mdy(1,1,5999)*24*3600;
    form_config_key=301;

    entity_number="9999";
    entity_name="Unknown institution";


    /* use default_ind to indicate that this institution is NOT the filing institution */    
    default_ind = 'N';
    output;




run;



%if &rc_debug = N %then
%do;
    proc sql;

         delete from rc_cfg.fincen_institution;
         
    quit;
    
    proc append base=rc_cfg.fincen_institution data=fincen_institution force;
    run;
     
%end;



/**********************************************************************************/
/* Sample branch data.                                                            */
/* This example shows how to integrate FSC_BRANCH_DIM data with branch            */
/* information in .csv that is specific for FinCEN e-files.                       */
/*                                                                                */
/* Branch number is used to merge data.                                           */
/* Same list of branches for SAR and CTR but different fields are used for        */
/* different forms.                                                               */
/**********************************************************************************/

data branch_extra;
      
     if 0 then set rc_cfg.fincen_branch;

     length effective_from_date_str 
            effective_to_date_str $ 20
            ;

     infile  rc_tmplt(rc_fincen_sample_branch_data.csv)  
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
     input 
          BRANCH_NUMBER             $ 
          BRANCH_ID                 $ 
          BRANCH_RSSD_ID            $
          BRANCH_GAMING_TYPE_CODE   $
          BRANCH_GAMING_TYPE_OTHER  $
          BRANCH_ID_TYPE_CODE       $
          BRANCH_PRIM_FED_REG_CODE  $
          BRANCH_TAX_ID             $
          BRANCH_TYPE_CTR_CODE      $
          BRANCH_TYPE_CTR_OTHER     $       
          effective_from_date_str $ 
          effective_to_date_str $
           
    ;

    
    effective_from_date=input(substr(effective_from_date_str,1,9),date9.)*24*3600;
    effective_to_date=input(substr(effective_to_date_str,1,9),date9.)*24*3600;     
    
    keep  
         branch_number branch_id branch_rssd_id branch_prim_fed_reg_code branch_tax_id
         branch_id_type_code branch_type_ctr_code branch_type_ctr_other branch_gaming_type_code
         branch_gaming_type_other effective_from_date effective_to_date parent_entity_number 
         ;
    /* sample logic to associate branches with institutions*/
    if branch_number < "1020000" then parent_entity_number="111222333";
    else if branch_number < '10260000' then parent_entity_number="222111333";
    else  parent_entity_number="333111222";
    
    
    
run;

proc sql;
    create table branch_combined as
    select extra.*, 
          dim.branch_key, 
          dim.branch_name length=100,         
          dim.street_address_1,
          dim.street_address_2,
          dim.street_city_name,
          dim.street_state_code,
          dim.street_postal_code          
 
     from branch_extra as extra,
          seg_kc.fsc_branch_dim as dim
     where extra.branch_number=dim.branch_number and
            dim.branch_key > 0
     ;
quit;

data fincen_branch;
     if 0 then set rc_cfg.fincen_branch;
     set branch_combined; 

     /* Required fields  */
     entity_number=branch_number;
     entity_name=branch_name;

     /* clean up branch data */
     branch_country_code='US';
      
     if street_address_1 ne '$' then
     do;
         if street_address_2 ne '$' then branch_address=strip(street_address_1)||' '||strip(street_address_2);
         else branch_address=street_address_1;
     end;
     if street_city_name ne '$' then branch_city_name=street_city_name;
     else branch_city_name='';
     if street_state_code ne '$' then branch_state_code=street_state_code;
     else branch_state_code='';
     if street_postal_code ne '$' then branch_zip_code=street_postal_code;
     else branch_zip_code='';
     drop 
          street_address_1 street_address_2  street_city_name street_state_code
                                     street_postal_code 
    ;
run;



%if &rc_debug = N %then
%do;
    proc sql;

         delete from rc_cfg.fincen_branch;
         
    quit;
    
   proc append base=rc_cfg.fincen_branch data=fincen_branch  force;
   run;
     
%end;
 

%mend;

%rc_load_sample_location;

%rc_refresh_entity_info;



