/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_validate_driver.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    validate report data and return an error report. 
|          
+------------------------------------------------------------------------------+
| USAGE: 
|          report_list     = report key list of reports to be validated 
|                            Keys are separated by ' ' 
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro rc_validate_driver(report_list=,form_config_key=,form_type_code=,extractDataYN=Y);

%let trans_rc=0;
%let _fcfmsg_=;

%let form_type_code=%trim(&form_type_code);


%if &extractDataYN ne N %then
%do;
   %rc_efile_fincen_data(report_list=&report_list,
                            form_config_key=&form_config_key,
                            form_type_code=&form_type_code
                        );
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: RC: Unable to extract data for validation;
         %fcf_put_error;
        %goto MACRO_END; 
    %end;
%end;
 
 data &form_type_code._error; 
      length error_record_type $ 2
             error_code        $ 4
             target_field_name $ 32
             report_key      8 
             entity_key      8
             entity_level_code $  32
         ;
         stop;
    run;
 
    proc sql noprint;
         select distinct trim(error_record_type) into
                :record_id_1 - 
         from rc_cfg.&form_type_code._fincen_error_code
         where error_record_type not in (' ', '1A', '2A')
         ;
         %let record_id_cnt=&sqlobs;
        
    quit;


    %inc rc_tmplt(rc_fincen_%lowcase(&form_type_code)_validation_code_macro.sas);

    %do irecord=1 %to &record_id_cnt;     
    
        %if %sysfunc(exist(&form_type_code._&&&record_id_&irecord)) %then
        %do;
        
             data _t_error;
             if 0 then set &form_type_code._error;
            set &form_type_code._&&&record_id_&irecord;
            keep error_record_type error_code report_key entity_level_code entity_key target_field_name ;
            retain error_record_type "&&&record_id_&irecord";
              %vldt_&form_type_code._&&&record_id_&irecord;
            run;
             

            %fcf_rcset(&syserr);
                        

            %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
                %let _fcfmsg_=ERROR: RC: Unable to validate WORK.&form_type_code._&&&record_id_&irecord;
                %fcf_put_error;
                %goto MACRO_END;
            %end;

         

 
            proc append base=&form_type_code._error data=_t_error (where=(error_code > '')) force;
            run;

               
            %fcf_rcset(&syserr);

            %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
                %let _fcfmsg_=ERROR: RC: Unable to append error table of WORK.&form_type_code._&&&record_id_&irecord to master error table;
                %fcf_put_error;
                %goto MACRO_END;
            %end;

         

        /* remove the temp table for the next cycle */
        proc sql noprint;
              drop table _t_error;
        quit;
        %end;
    %end;

    %vldt_&form_type_code;


        /**************************************/
        /* Obtain error description and types */
        /**************************************/

        %let error_cnt=0;
        proc sql;
        create table &form_type_code._error_more as 
        select a.report_key,  
               a.entity_level_code,
               a.entity_key, 
               b.*,
               c.target_field_short_desc
        from &form_type_code._error as a
        left join  rc_cfg.&form_type_code._fincen_error_code as b
        on a.error_code=b.error_code
           and a.error_record_type=b.error_record_type
        left join rc_cfg.form_efile_field_config as c
        on a.error_record_type=c.form_efile_record_id           
           and a.target_field_name=c.target_field_name
           and c.form_config_key=&form_config_key
        order by report_key, error_record_type, error_code
        ;
        %let error_cnt=&sqlobs;
        quit;  

         %fcf_rcset(&sqlrc);

         %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
             %let _fcfmsg_=ERROR: RC: Unable to create table &form_type_code._error_more;
             %fcf_put_error;
             %goto MACRO_END;
         %end;

         %if &error_cnt > 0 %then
         %do;

      
        /* Produce error reports */
        
         proc report data=&form_type_code._error_more nowindows center ;
 
             column report_key entity_key error_record_type error_code error_type_code  error_desc target_field_short_desc;

             define report_key /"Report Key";
             define entity_key /"Entity Key";
             define error_record_type /width=10 flow "Record Type";            
             define error_code /width=5 "Error Code" ;
             define error_type_code /width=10 format=$fincen_error_type. "Error Type"  ;
             define error_desc /width=30 flow "Error Description" ;  
             define target_field_short_desc /width=30 flow "Error Field" ;  

             title "Report %trim(&report_key) &form_type_code Validation Result - Error Reports";      

          run;
          %end;
          %else
          %do;
            options ls=72;
            data _null_;
                 file print;
                 put "No errors found for report: %trim(&report_list)";
            run;
          %end;

         %fcf_rcset(&syserr);

         %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
             %let _fcfmsg_=ERROR: RC: Unable to create table &form_type_code._error_more;
             %fcf_put_error;
             %goto MACRO_END;
         %end;        


%MACRO_END:    

  
    %if &trans_rc eq 3 or &trans_rc ge 5 %then 
      %fcf_execute_macro(fcf_error);
    %else %do;
      %fcf_execute_macro(fcf_success);
    %end;
   

%mend;
 
